==> script.module.dandyscrapers-17.11.11.zip: script.module.dandyscrapers/lib/dandyscrapers/scraperplugins/hollymoviehd.py <==
import re
from md_request import open_url
import xbmc
from ..scraper import Scraper
from ..common import clean_title,clean_search

User_Agent = 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/55.0.2883.87 Safari/537.36'
                                           
class hollymoviehd(Scraper):
    domains = ['https://www.hollymoviehd.com']
    name = "HollyMovieHD"
    sources = []

    def __init__(self):
        self.base_link = 'https://www.hollymoviehd.com'

                        

    def scrape_movie(self, title, year, imdb, debrid = False):
        try:
            search_id = clean_search(title.lower())
            start_url = '%s/?s=%s' %(self.base_link,search_id.replace(' ','+'))

            headers={'User-Agent':User_Agent}
            html = open_url(start_url,headers=headers, timeout=3).content

            match = re.compile('data-movie-id=.+?href="(.+?)" .+?class="mli-info"><h2>(.+?)</h2>',re.DOTALL).findall(html)
            for item_url, name in match:
                if year in name:
                    name=name.split('(')[0]
                    if clean_title(search_id).lower() == clean_title(name).lower():
                        self.get_source(item_url)
            return self.sources
        except:
            pass
            return[]

            
    def get_source(self,item_url):
        try:
            print 'MOVIE '+item_url
            headers={'User-Agent':User_Agent}
            OPEN = open_url(item_url,headers=headers, timeout=3).content
            #print OPEN
            holder = re.compile('data-lazy-src="(.+?)"',re.DOTALL).findall(OPEN)[0]
            if holder.startswith('//'):
                holder = 'https:' + holder
            print 'embfile'+holder
            headers={'User-Agent':User_Agent}
            
            Page = open_url(holder,headers=headers, timeout=3).content
            Endlinks = re.compile('file.+?(https://lh3.+?)"',re.DOTALL).findall(Page)
            for link in Endlinks:
                if '=m37' in link:
                    label = '1080p'
                elif '=m22' in link:
                    label = '720p'
                elif '=m59' in link:
                    label = 'DVD'
                else:
                    label = 'SD'
                print 'endlink %s - %s'%(link,label)
                self.sources.append({'source': 'GoogleLink', 'quality': label, 'scraper': self.name, 'url': link,'direct': True})           
        except:
            pass

==> script.module.dandyscrapers-17.11.13.zip: script.module.dandyscrapers/lib/dandyscrapers/scraperplugins/hollymoviehd.py <==
import re
from md_request import open_url
import xbmc
from ..scraper import Scraper
from ..common import clean_title,clean_search

User_Agent = 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/55.0.2883.87 Safari/537.36'
                                           
class hollymoviehd(Scraper):
    domains = ['https://www.hollymoviehd.com']
    name = "HollyMovieHD"
    sources = []

    def __init__(self):
        self.base_link = 'https://www.hollymoviehd.com'

                        

    def scrape_movie(self, title, year, imdb, debrid = False):
        try:
            search_id = clean_search(title.lower())
            start_url = '%s/?s=%s' %(self.base_link,search_id.replace(' ','+'))

            headers={'User-Agent':User_Agent}
            html = open_url(start_url,headers=headers, timeout=3).content

            match = re.compile('data-movie-id=.+?href="(.+?)" .+?class="mli-info"><h2>(.+?)</h2>',re.DOTALL).findall(html)
            for item_url, name in match:
                if year in name:
                    name=name.split('(')[0]
                    if clean_title(search_id).lower() == clean_title(name).lower():
                        self.get_source(item_url)
            return self.sources
        except:
            pass
            return[]

            
    def get_source(self,item_url):
        try:
            #print 'MOVIE '+item_url
            headers={'User-Agent':User_Agent}
            OPEN = open_url(item_url,headers=headers, timeout=3).content
            #print OPEN
            holder = re.compile('data-lazy-src="(.+?)"',re.DOTALL).findall(OPEN)[0]
            if holder.startswith('//'):
                holder = 'https:' + holder
            #print 'embfile'+holder
            headers={'User-Agent':User_Agent}
            
            Page = open_url(holder,headers=headers, timeout=3).content
            Endlinks = re.compile('file.+?(https://lh3.+?)"',re.DOTALL).findall(Page)
            for link in Endlinks:
                if '=m37' in link:
                    label = '1080p'
                elif '=m22' in link:
                    label = '720p'
                elif '=m59' in link:
                    label = 'DVD'
                else:
                    label = 'SD'
                #print 'endlink %s - %s'%(link,label)
                self.sources.append({'source': 'GoogleLink', 'quality': label, 'scraper': self.name, 'url': link,'direct': True})           
        except:
            pass
